API Reference
=============

Views
-----

This section lists documentation for all views available in Django Pydenticon.

.. automodule:: django_pydenticon.views
   :members:

URL
---

This section lists documentation for all URL-related functions available in
Django Pydenticon.

.. automodule:: django_pydenticon.urls
   :members:
